@@ -179,6 +179,11 @@ pub enum Error {
     #[error("unable to start track, codec is not supported by remote")]
     ErrUnsupportedCodec,
 
+    /// ErrSenderWithNoCodecs indicates that a RTPSender was created without any codecs. To send media the MediaEngine needs at
+    /// least one configured codec.
+    #[error("unable to populate media section, RTPSender created with no codecs")]
+    ErrSenderWithNoCodecs,
+
     /// ErrRTPSenderNewTrackHasIncorrectKind indicates that the new track is of a different kind than the previous/original
     #[error("new track must be of the same kind as previous")]
     ErrRTPSenderNewTrackHasIncorrectKind,
@@ -402,3 +407,13 @@ impl PartialEq<ice::Error> for Error {
         false
     }
 }
+
+/// flatten_errs flattens multiple errors into one
+pub fn flatten_errs(errs: Vec<impl Into<Error>>) -> Result<()> {
+    if errs.is_empty() {
+        Ok(())
+    } else {
+        let errs_strs: Vec<String> = errs.into_iter().map(|e| e.into().to_string()).collect();
+        Err(Error::new(errs_strs.join("\n")))
+    }
+}
